mod license;
mod device;
mod telemetry;
mod guard;
mod error;

pub use license::{License, LicenseFeature};
pub use guard::{init_guard, activate, check_feature, is_pro, max_monte_carlo_sims, min_resolution_secs, license_info, downgrade_to_community};
pub use error::LicenseError;
